@@ -1,13 +1,81 @@
 package Dist::Zilla::PluginBundle::Author::IOANR;
-$Dist::Zilla::PluginBundle::Author::IOANR::VERSION = '0.004';
+$Dist::Zilla::PluginBundle::Author::IOANR::VERSION = '0.005';
 # ABSTRACT: Build dists the way IOANR likes
 use v5.12;
 use Moose;
+use List::Util 1.33 'any';
+use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.107;
+use Dist::Zilla::Plugin::ContributorsFile;
+use Dist::Zilla::Plugin::ContributorsFromGit;
+use Dist::Zilla::Plugin::Git;
+use Dist::Zilla::Plugin::GitHub;
+use Dist::Zilla::Plugin::Meta::Contributors;
+use Dist::Zilla::Plugin::MetaData::BuiltWith;
+use Dist::Zilla::Plugin::ModuleBuildTiny;
+use Dist::Zilla::Plugin::PodWeaver 4.000;
+use Dist::Zilla::Plugin::ReadmeFromPod;
+use Dist::Zilla::Plugin::CopyFilesFromBuild;
+use Dist::Zilla::Plugin::RunExtraTests;
+use Dist::Zilla::Plugin::Signature;
+use Dist::Zilla::Plugin::Test::CheckDeps;
+use Dist::Zilla::Plugin::Test::Pod::No404s;
+use Dist::Zilla::Plugin::Test::ReportPrereqs;
+use Dist::Zilla::Plugin::Test::CPAN::Meta::JSON;
+use Dist::Zilla::Plugin::Test::Pod::LinkCheck;
+use Dist::Zilla::Plugin::Test::Version;
+use Dist::Zilla::Plugin::Test::Compile;
+use Dist::Zilla::Plugin::Test::DistManifest;
+use Dist::Zilla::Plugin::Test::EOL;
+use Dist::Zilla::Plugin::Test::Kwalitee;
+use Dist::Zilla::Plugin::Test::MinimumVersion;
+use Dist::Zilla::Plugin::MojibakeTests;
+use Dist::Zilla::Plugin::Test::NoTabs;
+use Dist::Zilla::Plugin::Test::Portability;
+use Dist::Zilla::Plugin::Test::Pod::No404s;
+use Dist::Zilla::Plugin::Test::Synopsis;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 # TODO optionally add OSPreqs
 
+has release_plugins => ( is => 'ro', lazy_build => 1);
+
+sub _build_release_plugins {
+    my $self = shift;
+
+    if ($self->payload->{fake_release} || $ENV{DZIL_FAKE_RELEASE}) {
+        return ['FakeRelease'];
+    }
+
+    return [
+        'ConfirmRelease',
+        ['Git::Commit' => {allow_dirty => [qw/README.mkdn dist.ini Changes/]}],
+        [
+            'Git::CommitBuild' => {
+                branch               => '',
+                release_branch       => 'release',
+                release_message      => 'Release %v',
+                multiple_inheritance => 1,
+            }
+        ],
+        'Git::Push',
+        ['Git::Tag' => {signed => 1, branch => 'release'}],
+        'GitHub::Update',
+        'UploadToCPAN',
+    ];
+}
+
+has build_plugin => (
+    is      => 'ro',
+    lazy    => 1,
+    default => sub {
+        if ($_[0]->payload->{custom_builder}) {
+            return [ModuleBuild => {mb_class => 'My::Builder'}];
+        } else {
+            return 'ModuleBuildTiny';
+        }
+    });
+
 sub mvp_multivalue_args {qw/disable assert_os/}
 
 sub configure {
@@ -19,111 +87,83 @@ sub configure {
         edit_changelog  => 1,
     };
 
-    if (exists $arg->{semantic_version} && $arg->{semantic_version}) {
+    if ($arg->{semantic_version}) {
         $change_opts->{tag_regexp} = 'semantic';
     }
 
-    $self->add_plugins([
-            'Git::GatherDir' => {
-                include_dotfiles => 1,
-                exclude_match    => '(Changes|README.mkdn)$'
-            },
-        ],
+    my @plugins = (
+        'AutoPrereqs',
+        ['ChangelogFromGit::CPAN::Changes' => $change_opts],
+        'ContributorsFile',
+        'ContributorsFromGit',
+        ['CopyFilesFromBuild' => {copy => [qw/README.md LICENSE/]}],
+        'ExecDir',
         [
             'Git::Check' => {
-                allow_dirty     => [qw/README.mkdn dist.ini Changes/],
+                allow_dirty     => [qw/README.md dist.ini Changes LICENSE/],
                 untracked_files => 'warn',
             }
         ],
-        ['PodWeaver'           => {config_plugin => '@Author::IOANR'}],
-        ['MetaData::BuiltWith' => {show_config   => 1}],
         [
-            ReadmeAnyFromPod => {
-                type     => 'markdown',
-                filename => 'README.mkdn',
-                location => 'root',
+            'Git::GatherDir' => {
+                include_dotfiles => 1,
+                exclude_match    => '(Changes|README.md|LICENSE)$',
             }
         ],
-        ['ChangelogFromGit::CPAN::Changes' => $change_opts],
-        qw/
-          AutoPrereqs
-          ContributorsFile
-          ContributorsFromGit
-          ExecDir
-          Git::NextVersion
-          License
-          Manifest
-          Meta::Contributors
-          MetaJSON
-          PkgVersion
-          PruneCruft
-          RunExtraTests
-          ShareDir
-          Signature
-          Test::CheckDeps
-          Test::ReportPrereqs
-          TestRelease
-          /,
+        'Git::NextVersion',
+        'GitHub::Meta',
+        'License',
+        'Manifest',
+        'Meta::Contributors',
+        ['MetaData::BuiltWith' => {show_config => 1}],
+        'MetaJSON',
+        ['PodWeaver' => {config_plugin => '@Author::IOANR'}],
+        'PkgVersion',
+        'PruneCruft',
+        'ShareDir',
+        'Signature',
+        ['ReadmeFromPod' => {type => 'markdown'}],
+        'MojibakeTests',
+        'Test::CheckDeps',
+        'Test::Compile',
+        'Test::CPAN::Meta::JSON',
+        'Test::DistManifest',
+        'Test::EOL',
+        ['Test::Kwalitee' => { skiptest => [qw/has_readme/]}],
+        'Test::MinimumVersion',
+        'Test::NoTabs',
+        'Test::Pod::LinkCheck',
+        'Test::Pod::No404s',
+        'Test::Portability',
+        'Test::ReportPrereqs',
+        'Test::Synopsis',
+        'Test::Version',
+        'TestRelease',
     );
 
-    # Test::Pod::No404s - links are being truncated?
-    $self->add_bundle(GitHub => {metacpan => 1});
+    # Test::UnusedVars
+    # Test::Perl::Critic
+    # PodCoverageTests
+    # PodSyntaxTests
 
-    # problem with DistManifest and Module::Build::Tiny - _build_params
-    $self->add_bundle(
-        TestingMania => {
-            disable => [
-                qw/MetaTests Test::Kwalitee Test::Perl::Critic Test::DistManifest/
-            ]});
+    push @plugins, @{$self->release_plugins};
 
-    if (!$arg->{fake_release}) {
-        $self->add_plugins([
-                'Git::CommitBuild' => {
-                    branch               => '',
-                    release_branch       => 'last_release',
-                    release_message      => 'Release %v',
-                    multiple_inheritance => 1,
-                }
-            ],
-            [
-                'Git::Commit' => {
-                    allow_dirty => [qw/README.mkdn dist.ini Changes/],
-                }
-            ],
-            ['Git::Tag' => {signed => 1, branch => 'last_release'}],
-            qw/
-              ConfirmRelease
-              Git::Push
-              UploadToCPAN
-              /
-        );
-    } else {
-        $self->add_plugins(qw/FakeRelease/);
+    my @add;
+    while (my $p = shift @plugins) {
+        next if any { $_ eq $p } @{$arg->{disable}};
+        push @add, $p;
     }
 
-    if (exists $arg->{custom_builder}) {
-        $self->add_plugins([
-            ModuleBuild => {mb_class => 'My::Builder'},
-        ]);
-    } else {
-        $self->add_plugins('ModuleBuildTiny');
-    }
+    push @add, $self->build_plugin;
+
+    # these have to come after the builder
+    push @add, 'RunExtraTests';
 
     if (exists $arg->{assert_os}) {
-        $self->add_plugins(
-            [AssertOS => $self->config_slice({assert_os => 'os'})]);
+        push @add, [AssertOS => $self->config_slice({assert_os => 'os'})];
     }
 
-    if (exists $arg->{disable}) {
-        my %plugins = map { $_->[1] => $_ } @{$self->plugins};
-
-        foreach my $plug_to_disable (@{$arg->{disable}}) {
-            delete $plugins{"Dist::Zilla::Plugin::$plug_to_disable"};
-        }
-
-        my $plugins_ref = $self->plugins;
-        @$plugins_ref = values %plugins;
-    }
+    $self->add_plugins(@add);
 
     return;
 }
@@ -137,7 +177,7 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Ioan Rogers <ioan@dirtysoft.ca> Sergey Romanov <sromanov-dev@yandex.ru>
+=for :stopwords Ioan Rogers Романов Сергей
 
 =head1 NAME
 
@@ -145,7 +185,7 @@ Dist::Zilla::PluginBundle::Author::IOANR - Build dists the way IOANR likes
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -273,7 +313,7 @@ Ioan Rogers <ioanr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Ioan Rogers.
+This software is Copyright (c) 2015 by Ioan Rogers.
 
 This is free software, licensed under:
 
